{% load aa_forum %}

<link
    rel="stylesheet"
    href="{% aa_forum_static 'aa_forum/css/aa-forum.min.css' %}"
    integrity="sha512-of5FeNjXq98ss4JU4Qp/EDRzdiV8QcxqN81oXoUzeLz4MuFaAqDAFjhlbXv9BEV5qgjkCoHXwZ/iMDc+G3zzLA=="
    crossorigin="anonymous"
>
